@@ -34,9 +34,9 @@ import Germinate.version
 
 # TODO: cloned from germinate.py; should be common
 SEEDS = ["http://people.canonical.com/~ubuntu-archive/seeds/"]
-RELEASE = "ubuntu.karmic"
+RELEASE = "ubuntu.lucid"
 MIRRORS = ["http://archive.ubuntu.com/ubuntu/"]
-DIST = ["karmic"]
+DIST = ["lucid"]
 COMPONENTS = ["main"]
 ARCH = "i386"
 
@@ -97,16 +97,16 @@ class Globals:
         global RELEASE, MIRRORS, DIST, COMPONENTS, ARCH
         print "Germinating"
         g = Germinator()
-        apt_pkg.InitConfig()
-        apt_pkg.Config.Set("APT::Architecture", ARCH)
-        apt_pkg.InitSystem()
+        apt_pkg.init_config()
+        apt_pkg.config.set("APT::Architecture", ARCH)
+        apt_pkg.init_system()
 
         Germinate.Archive.TagFile(MIRRORS).feed(
             g, DIST, COMPONENTS, ARCH, True)
 
         try:
-            seednames, seedinherit, seedbranches = g.parseStructure(SEEDS,
-                                                                    RELEASE)
+            seednames, seedinherit, seedbranches, _ = g.parseStructure(SEEDS,
+                                                                       RELEASE)
         except Germinate.seeds.SeedError:
             sys.exit(1)
         seednames, seedinherit, seedbranches = g.expandInheritance(
